#!/bin/bash

# Copyright (C) 2004-2010 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of le-proinfodata
#
# le-proinfodata is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This script will ask some configurations needed by the PROINFODATA agent

# Check if it's running on the live CD by checking the installation of ubiquity
if dpkg -l ubiquity-le 2>/dev/null | grep -q '^ii'; then
    # ubiquity is installed, so we are in the live CD. Exit.
    exit 0
fi

DIALOG="dialog --backtitle PROINFODATA --shadow --title"
TTY=/dev/tty1
TIMETOREAD=3

# LE ZONE
LEZONE=/etc/le-proinfodata/le.zone

# INEP file
SEED_HOME=/opt/seed_mec
INEPFILE="${SEED_HOME}/SEED2/client/conf/inep"
MD5INEPFILE="${SEED_HOME}/SEED2/.md5sum/client/conf/inep"
BACKUPINEPFILE="${SEED_HOME}/SEED2/.backup/client/conf/inep"
MD5BACKUPINEPFILE="${SEED_HOME}/SEED2/.md5sum/.backup/client/conf/inep"

# Proxy file
PROXYFILE="${SEED_HOME}/SEED2/client/conf/proxy"
MD5PROXYFILE="${SEED_HOME}/SEED2/.md5sum/client/conf/proxy"
BACKUPPROXYFILE="${SEED_HOME}/SEED2/.backup/client/conf/proxy"
MD5BACKUPPROXYFILE="${SEED_HOME}/SEED2/.md5sum/.backup/client/conf/proxy"

# "I'll do it later" message
LATER="quero digitar o inep da minha escola depois"

# Create a temp file to store some dialog answers.
ans=$(mktemp)

# test_exit exits if the given argument is equal to 255.
# This is used to test if the user pressed the ESC key.
function test_exit() {
    if test $1 -eq 255 ; then
        # Remove ans file.
        rm -f ${ans}
        # Start it again and exit.
        $0
        exit 0
    fi
}

# Welcome message
${DIALOG} PROINFODATA --msgbox "
O agente de acompanhamento do projeto PROINFODATA foi instalado nesta
máquina. Para torná-lo funcional, entretanto, é necessário fornecer
informações sobre as configurações de proxy, além do número INEP da
instituição. Para saber mais sobre o projeto, visite o site
http://seed.c3sl.ufpr.br ." 0 0 > ${TTY}

valid=1
while test ${valid} -ne 0; do
    # Ask INEP
    ${DIALOG} INEP --inputbox " Digite seu INEP ou a mensagem '${LATER}':" 0 0 > ${TTY} 2> ${ans}
    test_exit $?
    INEP=$(cat ${ans})

    # INEP empty, try again
    if test -z "${INEP}"; then
        continue
    fi

    # "Later" message?
    if [[ "${INEP}" == "${LATER}" ]]; then
        ${DIALOG} ATENÇÃO --msgbox "
O número INEP será requisitado novamente na próxima vez que este computador for ligado." 0 0 > ${TTY}
        clear > ${TTY}
        exit 0
    fi

    # Search the INEP in our base
    LINE=$(grep "^ ${INEP} " ${LEZONE})
    if [[ -z "${LINE}" ]]; then
        # Warning!
        ${DIALOG} ATENÇÃO --msgbox "
O INEP fornecido é inválido. Por favor verifique o número INEP
correspondente a sua instituição de ensino e tente novamente ou digite
'${LATER}'." 0 0 > ${TTY}
        valid=1
    else
        state=$(echo ${LINE} | awk -F'|' '{print $2}')
        city=$(echo ${LINE} | awk -F'|' '{print $3}')
        school=$(echo ${LINE} | awk -F'|' '{print $4}')
        zip=$(echo ${LINE} | awk -F'|' '{print $5}')

        ${DIALOG} Confirmação --yesno "\
INEP: ${INEP} \n\
Estado: ${state} \n\
Cidade: ${city} \n\
Escola: ${school} \n\
CEP: ${zip} \n\
Essas informações estão corretas?" 0 0 > ${TTY}
        valid=$?
        test_exit ${valid}
    fi
done

# INEP set. Ask for proxy configuration
${DIALOG}  proxy --yesno "Você possui informações de proxy?" 0 0 > ${TTY}
has_proxy=$?
test_exit ${has_proxy}
if test ${has_proxy} -eq 0; then

    valid=1
    while test ${valid} -ne 0; do

        declare -a formans
        ${DIALOG} proxy --form "Preencha as informações de proxy:" 12 55 5 \
            "Host:" 1 1 "" 1 20 100 100 \
            "Porta:" 2 1 "" 2 20 100 100 \
            "Usuario:" 3 1 "" 3 20 100 100 \
            > ${TTY} 2> ${ans}
        test_exit $?

        i=0
        while read line; do
            formans[${i}]=${line}
            (( i++ ))
        done < ${ans}

        phost=${formans[0]}
        pport=${formans[1]}
        puid=${formans[2]}


        equalpass=1
        while test ${equalpass} -ne 0 ; do
            ${DIALOG} proxy --insecure --passwordform "Preencha a senha do \
proxy, se necessário:" 12 55 5 \
                "Senha:" 1 1 "" 1 20 100 100 \
                "Confirmar Senha:" 2 1 "" 2 20 100 100 \
                > ${TTY} 2> ${ans}
            test_exit $?

            i=0
            while read line; do
                formans[${i}]=${line}
                (( i++ ))
            done < ${ans}

            if [[ "${formans[0]}" != "${formans[1]}" ]]; then
                ${DIALOG} proxy --sleep ${TIMETOREAD} --infobox "As senhas \
não conferem!" 0 0 > ${TTY}
            else
                equalpass=0
            fi
        done
        ppasswd=${formans[0]}

        ${DIALOG} Confirmação --yesno "\
Host: ${phost} \n\
Porta: ${pport} \n\
Usuário: ${puid} \n\
Essas informações estão corretas?" 0 0 > ${TTY}
        valid=$?
        test_exit ${valid}
    done
else
    phost=
    pport=
    puid=
    ppasswd=
fi

# set files
${DIALOG} PROINFO --msgbox "Processo concluido!" 0 0 > ${TTY}

# Set variables
echo "${INEP}" > ${INEPFILE}
echo "phost=${phost}" > ${PROXYFILE}
echo "pport=${pport}" >> ${PROXYFILE}
echo "puid=${puid}" >> ${PROXYFILE}
echo "ppasswd=${ppasswd}" >> ${PROXYFILE}

# Generate md5 hashs for the files
md5sum ${INEPFILE} | cut -d' ' -f1 > ${MD5INEPFILE}
md5sum ${PROXYFILE} | cut -d' ' -f1 > ${MD5PROXYFILE}

# Backup the files
cp ${INEPFILE} ${BACKUPINEPFILE}
cp ${PROXYFILE} ${BACKUPPROXYFILE}
cp ${MD5INEPFILE} ${MD5BACKUPINEPFILE}
cp ${MD5PROXYFILE} ${MD5BACKUPPROXYFILE}

chown seed_mec:seed_mec ${INEPFILE}
chown seed_mec:seed_mec ${PROXYFILE}

clear > ${TTY}
exit 0
